@@ -3,7 +3,6 @@
 // Purpose:     Unicode unit test
 // Author:      Vadim Zeitlin, Wlodzimierz ABX Skiba
 // Created:     2004-04-28
-// RCS-ID:      $Id$
 // Copyright:   (c) 2004 Vadim Zeitlin, Wlodzimierz Skiba
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -174,7 +173,7 @@ private:
 // register in the unnamed registry so that these tests are run by default
 CPPUNIT_TEST_SUITE_REGISTRATION( UnicodeTestCase );
 
-// also include in it's own registry so that these tests can be run alone
+// also include in its own registry so that these tests can be run alone
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION( UnicodeTestCase, "UnicodeTestCase" );
 
 UnicodeTestCase::UnicodeTestCase()
@@ -353,6 +352,13 @@ void UnicodeTestCase::ConversionUTF8()
         d.Test(n, conv);
         d.Test(n, wxConvUTF8);
     }
+
+    static const char* const u25a6 = "\xe2\x96\xa6";
+    wxMBConvUTF8 c(wxMBConvUTF8::MAP_INVALID_UTF8_TO_OCTAL);
+    CPPUNIT_ASSERT_EQUAL( 2, c.ToWChar(NULL, 0, u25a6, wxNO_LEN) );
+    CPPUNIT_ASSERT_EQUAL( 0, c.ToWChar(NULL, 0, u25a6, 0) );
+    CPPUNIT_ASSERT_EQUAL( 1, c.ToWChar(NULL, 0, u25a6, 3) );
+    CPPUNIT_ASSERT_EQUAL( 2, c.ToWChar(NULL, 0, u25a6, 4) );
 }
 
 void UnicodeTestCase::ConversionUTF16()
@@ -383,6 +389,11 @@ void UnicodeTestCase::ConversionUTF16()
     size_t len;
     conv.cMB2WC("\x01\0\0B\0C" /* A macron BC */, 6, &len);
     CPPUNIT_ASSERT_EQUAL( 3, len );
+
+    // Another one: verify that the length of the resulting string is computed
+    // correctly when there is a surrogate in the input.
+    wxMBConvUTF16BE().cMB2WC("\xd8\x03\xdc\x01" /* OLD TURKIC LETTER YENISEI A */, wxNO_LEN, &len);
+    CPPUNIT_ASSERT_EQUAL( 1, len );
 }
 
 void UnicodeTestCase::ConversionUTF32()
